==> haskell-xml-hamlet-0.5.0.2-189-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-Es9KtQbBENDC4SPjabkZ9P
key:                  xml-hamlet-0.5.0.2-Es9KtQbBENDC4SPjabkZ9P
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  5a4159bdded8a8300315403fbb2a5e42
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-Es9KtQbBENDC4SPjabkZ9P
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    shakespeare-2.1.0.1-Uy4jodBTwoFYAjbezW2JJ template-haskell-2.18.0.0
    text-1.2.5.0 xml-conduit-1.9.1.3-78hprMCLgMFFWPQU2FN158

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-203-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-LPKYqYHPYzX79uPwuhnG24
key:                  xml-hamlet-0.5.0.2-LPKYqYHPYzX79uPwuhnG24
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  09ffe4e6e287d487c26485b12f903615
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-LPKYqYHPYzX79uPwuhnG24
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    shakespeare-2.1.0.1-Gbrqdks1NkK7A5fj5vxRJN
    template-haskell-2.18.0.0 text-1.2.5.0
    xml-conduit-1.9.1.3-AwLhlaz27ql1567v7tH4L6

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
